@@ -52,11 +52,13 @@ FEATURES: dict[str, Any] = {
     "Items": {
         "Cat Food": basic.basic_items.edit_cat_food,
         "XP": basic.basic_items.edit_xp,
-        "Normal Tickets": basic.basic_items.edit_normal_tickets,
-        "Rare Tickets": basic.basic_items.edit_rare_tickets,
-        "Platinum Tickets": basic.basic_items.edit_platinum_tickets,
-        "Platinum Shards": basic.basic_items.edit_platinum_shards,
-        "Legend Tickets": basic.basic_items.edit_legend_tickets,
+        "Tickets": {
+            "Normal Tickets": basic.basic_items.edit_normal_tickets,
+            "Rare Tickets": basic.basic_items.edit_rare_tickets,
+            "Platinum Tickets": basic.basic_items.edit_platinum_tickets,
+            "Platinum Shards": basic.basic_items.edit_platinum_shards,
+            "Legend Tickets": basic.basic_items.edit_legend_tickets,
+        },
         "NP": basic.basic_items.edit_np,
         "Leadership": basic.basic_items.edit_leadership,
         "Battle Items": basic.basic_items.edit_battle_items,
@@ -75,20 +77,37 @@ FEATURES: dict[str, Any] = {
         "Fix gamatoto from crashing the game": gamototo.fix_gamatoto.fix_gamatoto,
     },
     "Cats / Special Skills": {
-        "Get Cats": cats.get_remove_cats.get_cat,
-        "Remove Cats": cats.get_remove_cats.remove_cats,
+        "Get / Remve Cats": {
+            "Get Cats": cats.get_remove_cats.get_cat,
+            "Remove Cats": cats.get_remove_cats.remove_cats,
+        },
         "Upgrade Cats": cats.upgrade_cats.upgrade_cats,
-        "True Form Cats": cats.evolve_cats.get_evolve,
-        "Force True Form Cats (will lead to blank cats for cats without a true form)": cats.evolve_cats.get_evolve_forced,
-        "Remove True Forms": cats.evolve_cats.remove_evolve,
-        "Talents": cats.talents.edit_talents,
-        "Collect / Remove Cat Guide": cats.clear_cat_guide.set_cat_guide,
+        "True Form Cats": {
+            "Get Cat True Forms": cats.evolve_cats.get_evolve,
+            "Remove Cat True Forms": cats.evolve_cats.remove_evolve,
+            "Force True Form Cats (will lead to blank cats for cats without a true form)": cats.evolve_cats.get_evolve_forced,
+        },
+        "Talents": {
+            "Set talents for each selected cat individually": cats.talents.edit_talents_individual,
+            "Max / Remove all selected cat talents": cats.talents.max_all_talents,
+        },
+        "Collect / Remove Cat Guide": {
+            "Set Cat Guide Entries (does not give cf)": cats.clear_cat_guide.collect_cat_guide,
+            "Unclaim Cat Guide Entries": cats.clear_cat_guide.remove_cat_guide,
+        },
         'Get stage unit drops - removes the "Clear this stage to get special cat" dialog': cats.chara_drop.get_character_drops,
         "Upgrade special skills / abilities": cats.upgrade_blue.upgrade_blue,
     },
     "Levels / Treasures": {
-        "Main Story Chapters Clear / Unclear": levels.main_story.edit_main_story,
-        "Main Story Treasures": levels.treasures.specific_treasures,
+        "Main Story Chapters Clear / Unclear": {
+            "Clear each stage in every chapter for all selected chapters": levels.main_story.clear_all,
+            "Clear each stage in every chapter for each selected chapter": levels.main_story.clear_each,
+        },
+        "Treasures": {
+            "Treasure Groups (e.g energy drink, aqua crystal, etc)": levels.treasures.treasure_groups,
+            "Specific stages and specific chapters individually": levels.treasures.specific_stages,
+            "Specific stages and chapters all at once": levels.treasures.specific_stages_all_chapters,
+        },
         "Zombie Stages / Outbreaks": levels.outbreaks.edit_outbreaks,
         "Event Stages": levels.event_stages.event_stages,
         "Stories of Legend": levels.event_stages.stories_of_legend,
